import objectdraw.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class StringDemos extends Controller implements ActionListener {

	public static final int FIELDWIDTH = 40;  // width of textfields
	
	// Choice used to indicate which of the String methods user wants to
	// experiment with
	private JComboBox selector;

	// Button used to invoke operation once input are filled in
	private JButton doTest;

	// Object of class appropriate for exercising method selected by user
	private StringOpTester tester;

	// Field used to display the result of an invocation
	private LabeledTextField result;

	// Construct user interface items when program starts
	public void begin() {

		// Construct the controls
		// Panel used to hold choice and doTest button
//		Panel controls = new SizeablePanel(600, 30);
		JPanel controls = new JPanel();

		doTest = new JButton("Show Result");
		doTest.setFont(new Font("Times", Font.PLAIN, 18));
		doTest.addActionListener(this);
		controls.add(doTest);
		System.out.println("abcabc".lastIndexOf("abc"));

		selector = new JComboBox();
		selector.addItem( new CharAtTester() );
		selector.addItem( new EqualsTester() );
		selector.addItem( new EqualsIgnoreTester() );
		selector.addItem( new EndsWithTester() );
		selector.addItem( new IndexOfTester() );
		selector.addItem( new LastIndexTester() );
		selector.addItem( new LengthTester() );
		selector.addItem( new ToLowerTester() );
		selector.addItem( new ToUpperTester() );
		selector.addItem( new StartsWithTester() );
		selector.addItem( new SubStringTester() );
		selector.addActionListener(this);
		controls.add(selector);


		Container contentPane = getContentPane();
		contentPane.add(controls, BorderLayout.NORTH);

		// Add panel of controls for method initially displayed by "selector"
		tester = (StringOpTester)selector.getSelectedItem();
		contentPane.add(tester.getPanel(), BorderLayout.CENTER);

		// Add result display area
		result = new LabeledTextField("Result:", FIELDWIDTH);
		contentPane.add(result, BorderLayout.SOUTH);

	}

	// When the button is clicked, perform the requested operation
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == doTest){
		result.setText(tester.doIt());
		} else {
			StringOpTester newtester;

			remove(tester.getPanel());
			newtester = (StringOpTester)selector.getSelectedItem();
			newtester.copyInputs(tester);
			Container contentPane = getContentPane();
			contentPane.add(newtester.getPanel(), BorderLayout.CENTER);
			tester = newtester;
			validate();
		}
	}

}
